@@ -12,7 +12,8 @@ sub envs
 
     $cnt++;
 
-    return { Site1_App1 => $cnt, %{$opt} };
+    warn( "Site1 App1 $cnt\n" ) if $ENV{APP_ENV_DEBUG};
+    return { %ENV, Site1_App1 => $cnt, %{$opt} };
 }
 
 sub reset
